from django.db import models


class Artist(models.Model):
    artist_name = models.CharField(max_length=200)
    birth_name = models.CharField(max_length=200, default=artist_name)
    bio = models.CharField(
        max_length=700,
        default="No information available.",
    )
    monthly_listeners = models.IntegerField(default=0)

    def __str__(self):
        return self.artist_name


class Album(models.Model):
    album_name = models.CharField(max_length=250)
    artist = models.ForeignKey(
        "Artist",
        on_delete=models.CASCADE,
    )
    description = models.CharField(max_length=500)
    release_date = models.DateField(
        auto_now=False,
        auto_now_add=False,
    )
    label = models.CharField(
        max_length=250,
        blank=True,
    )
    song_count = models.IntegerField(null=True)

    def __str__(self):
        return "{} by {}".format(self.album_name, self.artist)


class Song(models.Model):
    song_title = models.CharField(max_length=250)
    artist = models.ForeignKey(
        "Artist",
        on_delete=models.CASCADE,
    )
    album = models.ForeignKey(
        "Album",
        on_delete=models.CASCADE,
    )
    song_length = models.PositiveIntegerField()
    music_video = models.BooleanField(default=False)
    lyrics = models.TextField(default="Unknown lyrics.")

    def __str__(self):
        return "{} by {} from {}".format(self.song_title, self.artist, self.album)
